
### 210301 sgMib1 V-GFP 24h

# Prepare all the packages that you are going to use along the pipeline 

library("tidyr")
library("tidyverse")
library("dplyr")

library("stringr")
library("ggplot2")

library("lattice")
library("gplots")

# Set your working directory --------------------------------------------------------------------------------------------

setwd("N://Alfonso_Gomez//1 - Experimental Procedures//210301_sgMib1_VGFP_24h//CellProfAnalys")

Plate20 <- read.csv2("210301_sgMib_VGFP_24h_Nucleus.csv", header = T, sep = ",")

Plate20 <- as.data.frame(Plate20)

as.numeric.factor <- function(x){
  as.numeric(levels(x))[x]
}

add_my_numbers <- function(data){
  a <- str_split_fixed(data$Metadata_Well,"",n = 2)
  L <- as.character(a[,1])
  N <- as.numeric(a[,2])
  data <- cbind(data, "Letter_Well"=L,"Number_Well"=N)
  return(data)
}

Titration_calculations <- function(Plate){
  Plate <- as.data.frame(Plate)
  Separate_me <- str_split_fixed(Plate$Metadata_Well,"",n = 2)
  Plate <- cbind(Plate, "Letter_Well"= as.character(Separate_me[,1]),"Number_Well"= as.numeric(Separate_me[,2]))
  Plate$Intensity_MeanIntensity_GFP <- as.numeric.factor(Plate$Intensity_MeanIntensity_GFP)
  Plate$Intensity_MeanIntensity_pVI <- as.numeric.factor(Plate$Intensity_MeanIntensity_pVI)
  Ref_background_intensity_pVI <- mean(Plate[Plate$Number_Well== 2,]$Intensity_MeanIntensity_pVI)
  Ref_threshold_pVI <- quantile(Plate[Plate$Number_Well== 2,]$Intensity_MeanIntensity_pVI, c(0.999))
  Ref_background_intensity_GFP <- mean(Plate[Plate$Number_Well== 2,]$Intensity_MeanIntensity_GFP)
  Ref_threshold_GFP <- quantile(Plate[Plate$Number_Well== 2,]$Intensity_MeanIntensity_GFP, c(0.999))
  Plate_size <- unique(Plate$Metadata_Well, incomparables = FALSE)
  Output <- matrix(nrow = length(Plate_size),ncol = 8)
  for (f in seq_along(Plate_size)) {
    Well <- as.character(Plate_size[f])
    Well_matrix <- Plate[Plate$Metadata_Well== Well,]
    Cells <- dim(Well_matrix)[1]
    Mean_intensity_pVI <- mean(Well_matrix$Intensity_MeanIntensity_pVI)
    Infected_cells_pVI <- dim(Well_matrix[Well_matrix$Intensity_MeanIntensity_pVI >= Ref_threshold_pVI,])[1]
    Percent_inf_pVI <- (Infected_cells_pVI/Cells)*100
    Mean_intensity_GFP <- mean(Well_matrix$Intensity_MeanIntensity_GFP)
    Infected_cells_GFP <- dim(Well_matrix[Well_matrix$Intensity_MeanIntensity_GFP >= Ref_threshold_GFP,])[1]
    Percent_inf_GFP <- (Infected_cells_GFP/Cells)*100
    Output[f,] <- c(Well, Cells, Mean_intensity_pVI, Infected_cells_pVI, Percent_inf_pVI,
                    Mean_intensity_GFP, Infected_cells_GFP, Percent_inf_GFP)
  }
  colnames(Output) <- c("Plate_Well", "Cells_in_Well","Mean_pIV_intensity", "Infected_cells", "Percentage_infected_cells",
                        "Mean_GFP_intensity", "GFP_cells", "Percentage_GFP_cells")
  Output <- as.data.frame(Output)
  Output$Cells_in_Well <- as.numeric.factor(Output$Cells_in_Well)
  Output$Mean_pIV_intensity <- as.numeric.factor(Output$Mean_pIV_intensity)
  Output$Infected_cells <- as.numeric.factor(Output$Infected_cells)
  Output$Percentage_infected_cells <- as.numeric.factor(Output$Percentage_infected_cells)
  Output$Mean_GFP_intensity <- as.numeric.factor(Output$Mean_GFP_intensity)
  Output$GFP_cells <- as.numeric.factor(Output$GFP_cells)
  Output$Percentage_GFP_cells <- as.numeric.factor(Output$Percentage_GFP_cells)
  return(Output)
}

Titration_good <- Titration_calculations(Plate20)

ggplot()+
  geom_point(data = Titration_good,aes(x = Plate_Well,y = Percentage_infected_cells), color="red") +
  #ylim(0,30)+
  ylab("Relative GFP intensity") +
  xlab("Well")+
  ggtitle(paste("siRNA set","1",sep = " ")) + 
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1))

ggplot()+
  geom_point(data = Titration_good,aes(x = Plate_Well,y = Percentage_GFP_cells), color="red") +
  #ylim(0,30)+
  ylab("Relative GFP intensity") +
  xlab("Well")+
  ggtitle(paste("siRNA set","1",sep = " ")) + 
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1))


write.csv2(Titration_good, file = "210302_sgMib1_V-GFP_24h_calculations.csv")
